/*
 * Copyright (c) 2015, Xilinx Inc. and Contributors. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * @file	gcc/atomic.h
 * @brief	GCC specific atomic primitives for libmetal.
 */

#ifndef __METAL_AARCH64_ATOMIC__H__
#define __METAL_AARCH64_ATOMIC__H__

#endif /* __METAL_ARM_ATOMIC__H__ */
